Output processor
================
.. currentmodule:: biobroker.output_processor

.. autosummary::
   :nosignatures:

    GenericOutputProcessor
    TsvOutputProcessor
    XlsxOutputProcessor

.. automodule:: biobroker.output_processor
   :members:
   :undoc-members:
   :show-inheritance:
